#
# spec file for package qwt
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libqwt5-qt5-5
Name:           qwt
Version:        5.2.3_qt5+git20181129.2819734
Release:        3.24
Summary:        Qt Widgets for Technical Applications
License:        SUSE-QWT-1.0
Group:          Development/Libraries/C and C++
URL:            http://qwt.sourceforge.net/
Source:         qwt-%{version}.tar.xz
# PATCH-FIX-UPSTREAM qwt-Qt_5.13.patch
Patch0:         qwt-Qt_5.13.patch
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
The Qwt library contains GUI Components and utility classes which are
primarily useful for programs with a technical background. Beside a 2D
plot widget it provides scales, sliders, dials, compasses, thermometers,
wheels and knobs to control or display values, arrays, or ranges of type
double.

%package -n %{lname}
Summary:        Shared library for Qt Widgets
Group:          Development/Libraries/C and C++

%description -n %{lname}
This package contains the shared library to run Technical Applications
developed with/for qwt.

%package devel
Summary:        Include headers and Qt Designer plugin for Qwt
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       freetype2-devel
Requires:       gcc-c++
Requires:       libpng-devel
Recommends:     %{name}-devel-doc
Obsoletes:      libqwt5-devel < %{version}
Provides:       libqwt5-devel = %{version}
Provides:       qwt = %{version}

%description devel
This package contains the header files of Qwt and its Qt designer plugin
in order to create Qt applications using the Qwt widgets.

%package designer
Summary:        Plugin for the Qt Interface designer
Group:          Development/Tools/IDE
Requires:       %{name}-devel = %{version}

%description designer
The %{name}-designer package contains the plugin for the Qt User Interface
designer tool.

%package devel-doc
Summary:        Development documentation for Qwt
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
# Both provide deprecated(3) man page
Conflicts:      libftdi1-devel
Provides:       libqwt5-devel-doc = %{version}
Obsoletes:      libqwt5-devel-doc < %{version}

%description devel-doc
This package contains the development documentation of the Qwt widgets
as is it created by doxygen.

%prep
%setup -q -n qwt-%{version}
%patch0 -p1

# qmake is so fun...
sed -i 's|headers.path   = \$\$\[QT_INSTALL_HEADERS\]/qwt5-qt5|headers.path   = %{_libqt5_includedir}/qwt5|' qwtconfig.pri
sed -i 's|doc.path       = \$\$\[QT_INSTALL_DOCS\]|doc.path       = %{_libqt5_docdir}/qwt5|' qwtconfig.pri
sed -i 's|html.path      = \$\$\[QT_INSTALL_DOCS\]/html/qwt5-qt\$\$QT_MAJOR_VERSION|html.path      = %{_libqt5_docdir}/qwt5/html|' src/src.pro

%build
%qmake5 \
  INSTALLBASE=%{_prefix} \
  CONFIG-=QwtExamples

make %{?_smp_mflags}

%install
%qmake5_install

%fdupes -s %{buildroot}

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING
%doc CHANGES README
%{_libqt5_libdir}/libqwt5-qt5.so.*

%files designer
%dir %{_libqt5_plugindir}/designer/
%{_libqt5_plugindir}/designer/*.so

%files devel
%{_libqt5_includedir}/qwt5/
%{_libqt5_libdir}/libqwt5-qt5.so
%{_libqt5_libdir}/pkgconfig/qwt5-qt5.pc
%{_mandir}/man?/*.?%{ext_info}

%files devel-doc
%doc %{_libqt5_docdir}/qwt5

%changelog
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix build with recent libqt5-qttools packages.
* Sun Jul 21 2019 Luigi Baldoni <aloisio@gmx.com>
- Added qwt-Qt_5.13.patch to fix Factory build
* Wed Apr 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use a Qt5 snapshot for qwt, needed by scidavis 1.25.
- Run spec-cleaner
- Drop the examples package. qwt5 has only one user.
* Sat Feb  1 2014 hrvoje.senjan@gmail.com
- updated to version 5.2.3
  * Several minor bug fixes
- Smaller spec cleanup: remove ancient distro checks
- Added Conflicts with libftdi1-devel for devel-doc subpackage, both
  provide deprecated(3) man page
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Wed Jun 20 2012 cfarrell@suse.com
- license update: SUSE-QWT-1.0
  SPDX format (or choose from list linked at license.opensuse.org)
* Wed Nov 30 2011 idoenmez@suse.de
- Add Provides for qwt package, no need for obsoletes since the base
  package never really existed.
- Simplify filelist
* Tue Nov 29 2011 Nico.Laus.2001@gmx.de
- removed dependency of the devel package to the (non-existing)
  base package
* Mon Nov 28 2011 idoenmez@suse.de
- Remove nearly empty qwt base package again
* Sat Nov 26 2011 chris@computersalat.de
- readd tests for other distributions
- cleanup doc files
  * mv pdf to devel-doc
  * mv man to devel-doc
- CHANGES, COPYING, README to qwt pkg
  * no extra files in libqwt5 pkg
- fix rpmlintrc file
- fix build for SLE_10
  * directories not owned by a package: %%{_libdir}/qt4/....
* Fri Oct 21 2011 mls@suse.de
- do not use /usr/src/packages in specfile
* Thu Aug  4 2011 toddrme2178@gmail.com
- Changed include dir from qwt to qwt5.
  This will make it more compatible with qwt6,
  which is out but not well-supported yet
- Removed build flags that are enabled by default.
- Added building of svg item support.
  This is needed by the bindings packages
- Cleaned up spec file formatting.
* Thu Aug  4 2011 toddrme2178@gmail.com
- updated to version 5.2.2
- add pdf documentation package
- remove tests for other distributions
- move contents of the "qwt" package into libqwt5
  it just had the license, readme, and changelog
- remove patch (enable-svg.diff) that is now included upstream
* Wed Apr 14 2010 koprok@nand.bg
- updated to version 5.2.1
- fix parallel make patch is not needed any more
* Fri Jan  1 2010 chris@computersalat.de
- spec mods
  o added header
  o cleanup
  o fixed fdupes deps >= 1100
  o replaced libqt4-devel >= 4.3 to qt-devel
  * Qwt 5.x might be usable in all environments where you find Qt.
    It is compatible with Qt 3.3.x and Qt 4.x
* Tue Nov 24 2009 koprok@nand.bg
- fix parallel make
* Sun Aug 30 2009 lars@linux-schulserver.de
- original taken from Education:Salome:Factory
- use the original name for the package and provide/obsolete
  the libqwt5* names
- use qmake vars instead of patching the sources
- split off designer package and put the lib to the right place
- added rpmlintrc
* Thu May  7 2009 Nico.Laus.2001@gmx.de
- made compile on Fedora, Mandriva
- removed unnecessary (Build)Requires
* Sun Mar 29 2009 Nico.Laus.2001@gmx.de
- updated to version 5.2.0
- changed config to enable QwtPlotSvgItem
* Tue Mar 24 2009 Nico.Laus.2001@gmx.de
- added sub-packages examples and devel-doc
- added documentation
  Fri May 16 00:00:00 CET 2008 - 0.pm.1
- rebuild for PackMan
* Wed Nov 21 2007 opensuse@dstoecker.de
- better installation
- some fixes
* Tue Jun 26 2007 opensuse@dstoecker.de
- updated to release 5.0.2
- now a openSUSE BuildService project
  Wed Jan 03 00:00:00 CET 2007 - Christian Härtwig 5.0.0
- updated to CVS20070103 (5.0.0)
- renamed package to libqwt5
- modified package to coexist together with libqwt-4.2.0 from Quentin Denis
- added examples to -devel package
  Mon Aug 28 00:00:00 CET 2006 - Christian Härtwig 5.0.0
- initial version CVS20060828 (5.0.0)
